==> route_transition_yr-0.0.1.tar.gz: lib/route_transition_yr.dart <==

import 'package:flutter/material.dart';

enum AnimationType {
  normal,
  fadeIn,
  fadeInUp
}

class RouteTransitions {

  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions({
    required this.context, 
    required this.child, 
    this.replacement = false,
    this.animation = AnimationType.normal,
    this.duration = const Duration(milliseconds: 300),
  }) {

    switch (animation) {
      
      case AnimationType.normal:
        _normalTransition();
        break;
      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
      case AnimationType.fadeInUp:
        _fadeInUpTransition();
        break;
    }

  }

  void _pushRoute(Route route) {
    if (replacement) {
      Navigator.pushReplacement(context, route);
    } else {
      Navigator.push(context, route);
    }
  }

  void _normalTransition() {

    final route = MaterialPageRoute(builder:  (_) => child);
    _pushRoute(route);
    
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) => child,
      transitionDuration: duration,
      transitionsBuilder: (_, animation, __, child) {
        return FadeTransition(
          child: child,
          opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
            CurvedAnimation(
              parent: animation,
              curve:  Curves.easeOut
            ),
          ),
        );
      },
    );
    _pushRoute(route);
  }

  void _fadeInUpTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) => child,
      transitionDuration: duration,
      transitionsBuilder: (context, animation, secondaryAnimation, child) {
        var begin = const Offset(0.0, 1.0);
        var end = Offset.zero;
        var curve = Curves.ease;

        var tween = Tween(begin: begin, end: end).chain(CurveTween(curve: curve));

        return SlideTransition(
          position: animation.drive(tween),
          child: child,
        );
      },
    );

    _pushRoute(route);
  }
}

==> route_transition_yr-0.0.3.tar.gz: lib/route_transition_yr.dart <==
import 'package:flutter/material.dart';

/// The type of the transition for a route.
enum AnimationType {
  normal,
  fadeIn,
  fadeInUp,
  fadeInRight,
  fadeInLeft,
  fadeInDown,
}

/// The [RouteTransition] class is used to animate the transition between routes.
/// [child] is the widget that will be animated.
/// [animationType] is the type of animation.
/// [duration] is the duration of the animation.
class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions({
    required this.context,
    required this.child,
    this.replacement = false,
    this.animation = AnimationType.normal,
    this.duration = const Duration(milliseconds: 300),
  }) {
    switch (animation) {
      case AnimationType.normal:
        _normalTransition();
        break;
      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
      case AnimationType.fadeInUp:
        _fadeInUpTransition();
        break;
      case AnimationType.fadeInRight:
        _fadeInRightTransition();
        break;
      case AnimationType.fadeInLeft:
        _fadeInLeftTransition();
        break;
      case AnimationType.fadeInDown:
        _fadeInDownTransition();
        break;
    }
  }

  void _pushRoute(Route route) {
    if (replacement) {
      Navigator.pushReplacement(context, route);
    } else {
      Navigator.push(context, route);
    }
  }

  /// The normal transition.
  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => child);
    _pushRoute(route);
  }

  /// The fade in transition.
  void _fadeInTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) => child,
      transitionDuration: duration,
      transitionsBuilder: (_, animation, __, child) {
        return FadeTransition(
          child: child,
          opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
            CurvedAnimation(parent: animation, curve: Curves.easeOut),
          ),
        );
      },
    );
    _pushRoute(route);
  }

  /// The fade in up transition.
  void _fadeInUpTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) => child,
      transitionDuration: duration,
      transitionsBuilder: (context, animation, secondaryAnimation, child) {
        var begin = const Offset(0.0, 1.0);
        var end = Offset.zero;
        var curve = Curves.ease;

        var tween =
            Tween(begin: begin, end: end).chain(CurveTween(curve: curve));

        return SlideTransition(
          position: animation.drive(tween),
          child: child,
        );
      },
    );

    _pushRoute(route);
  }

  /// The fade in right transition.
  void _fadeInRightTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) => child,
      transitionDuration: duration,
      transitionsBuilder: (context, animation, secondaryAnimation, child) {
        var begin = const Offset(1.0, 0.0);
        var end = Offset.zero;
        var curve = Curves.ease;

        var tween =
            Tween(begin: begin, end: end).chain(CurveTween(curve: curve));

        return SlideTransition(
          position: animation.drive(tween),
          child: child,
        );
      },
    );

    _pushRoute(route);
  }

  /// The fade in left transition.
  void _fadeInLeftTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) => child,
      transitionDuration: duration,
      transitionsBuilder: (context, animation, secondaryAnimation, child) {
        var begin = const Offset(-1.0, 0.0);
        var end = Offset.zero;
        var curve = Curves.ease;

        var tween =
            Tween(begin: begin, end: end).chain(CurveTween(curve: curve));

        return SlideTransition(
          position: animation.drive(tween),
          child: child,
        );
      },
    );

    _pushRoute(route);
  }

  /// The fade in down transition.
  void _fadeInDownTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (context, animation, secondaryAnimation) => child,
      transitionDuration: duration,
      transitionsBuilder: (context, animation, secondaryAnimation, child) {
        var begin = const Offset(0.0, -1.0);
        var end = Offset.zero;
        var curve = Curves.ease;

        var tween =
            Tween(begin: begin, end: end).chain(CurveTween(curve: curve));

        return SlideTransition(
          position: animation.drive(tween),
          child: child,
        );
      },
    );

    _pushRoute(route);
  }
}
